# daf_relation

[![pypi](https://img.shields.io/pypi/v/lsst-daf-relation.svg)](https://pypi.org/project/lsst-daf-relation/)
[![codecov](https://codecov.io/gh/lsst/daf_relation/branch/main/graph/badge.svg?token=2BUBL8R9RH)](https://codecov.io/gh/lsst/daf_relation)

`daf_relation` is a package in the [LSST Science Pipelines](https://pipelines.lsst.io).

This package provides classes that represent relational algebra expression trees, along with algorithms to convert them to SQLAlchemy objects and Python generators.

PyPI: [lsst-daf-relation](https://pypi.org/project/lsst-daf-relation/)
